# Gotta Go Super Fast!
### Web Scraping API to outsource TONS of GET requests and xpath to aws lambda units  
![demo](/images/demo.gif)
![Powered by AWS Cloud Computing](https://d0.awsstatic.com/logos/powered-by-aws.png "Powered by AWS Cloud Computing")
# Performance Example and System Flowchart
+ 6939 requests to get all stock prices from www.nasdaq.com in 162 seconds  
+ 10000 requests to get new questions from www.stackoverflow.com in 142 seconds  

![flowchart](/images/flowchart.jpg)
# 3 dollars & 5 minutes = 10,000 scraping
 (not implemented. don't pay yet)
+ [PayPal page to buy api key](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=RBWEMYUS7FCF6)
https://www.sandbox.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=LLWKDGWZRFQ94 ![Paypal](https://www.paypalobjects.com/webstatic/en_US/i/buttons/PP_logo_h_100x26.png)

[![paypal](https://www.sandbox.paypal.com/en_US/i/btn/btn_cart_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=LLWKDGWZRFQ94)
